@@ -11,12 +11,12 @@
 
 #include "AI/KBlocksAILog.h"
 
-KBlocksNetPlayer::KBlocksNetPlayer(GamePlayerInterface * player, const string& serverIP, int localPort)
+KBlocksNetPlayer::KBlocksNetPlayer(GamePlayerInterface *player, const string &serverIP, int localPort)
 {
     mpNetClient = new KBlocksNetClient(serverIP.c_str(), localPort);
-    
+
     mpPlayer = player;
-    
+
     mActionList.clear();
 }
 
@@ -30,19 +30,18 @@ void KBlocksNetPlayer::joinGame(int gameIndex)
     int tmpByteCount = 0;
     char tmpByteData[256];
     string tmpName = mpPlayer->getName();
-    
+
     tmpByteData[tmpByteCount++] = '|';
     tmpByteData[tmpByteCount++] = 'a';
     tmpByteData[tmpByteCount++] = 'p';
     tmpByteData[tmpByteCount++] = '|';
     tmpByteData[tmpByteCount++] = (char)gameIndex + '0';
     tmpByteData[tmpByteCount++] = '|';
-    for(size_t i = 0; i < tmpName.length(); ++i)
-    {
+    for (size_t i = 0; i < tmpName.length(); ++i) {
         tmpByteData[tmpByteCount++] = (char)tmpName[i];
     }
     tmpByteData[tmpByteCount++] = 0;
-    
+
     mpNetClient->sendData(tmpByteCount, tmpByteData);
 }
 
@@ -52,14 +51,14 @@ void KBlocksNetPlayer::quitGame()
     mpNetClient->sendData(5, tmpByteData);
 }
 
-void KBlocksNetPlayer::startGame(KBlocksSingleGame * p)
+void KBlocksNetPlayer::startGame(KBlocksSingleGame *p)
 {
     char tmpByteData[4] = {'|', 's', '|', '\0'};
     mpNetClient->sendData(4, tmpByteData);
-    
+
     mpGame = p;
     mpPlayer->startGame(mpGame);
-    
+
     mActionList.clear();
 }
 
@@ -67,89 +66,75 @@ void KBlocksNetPlayer::stopGame()
 {
     char tmpByteData[4] = {'|', 'c', '|', '\0'};
     mpNetClient->sendData(4, tmpByteData);
-    
+
     mpPlayer->stopGame();
     mpGame = 0;
-    
+
     mActionList.clear();
 }
 
 bool KBlocksNetPlayer::execute()
 {
     bool execResult = true;
-    char* tmpByteData = new char[256];
-    
+    char *tmpByteData = new char[256];
+
     int ret = mpNetClient->recvData(256, tmpByteData);
-    if (ret < 0)
-    {
+    if (ret < 0) {
         // Do nothing...
         //printf("--Nothing received\n");
-    }
-    else if (tmpByteData[0] == -1)
-    {
+    } else if (tmpByteData[0] == -1) {
         mSendLength = (unsigned char)tmpByteData[1];
         //printf("--Send Length = %d\n", mSendLength);
-    }
-    else if (tmpByteData[0] == 127)
-    {
+    } else if (tmpByteData[0] == 127) {
         execResult = false;
         //printf("--Game Ended\n");
-    }
-    else
-    {
+    } else {
         //printf("++Game Updates (%d) of [%d bytes]\n", (int)tmpByteData[0], ret);
         int tmpPieceCount = formIntFromByte(tmpByteData + 13);
-        for (int i = 0; i < tmpPieceCount; ++i)
-        {
-            mpGame->getPiece(i)->decodeData((unsigned char*)tmpByteData + 17 + i * 4);
+        for (int i = 0; i < tmpPieceCount; ++i) {
+            mpGame->getPiece(i)->decodeData((unsigned char *)tmpByteData + 17 + i * 4);
         }
-        
-        mpGame->getField()->decodeData((unsigned char*)tmpByteData + 18 + tmpPieceCount * 4);
-        
+
+        mpGame->getField()->decodeData((unsigned char *)tmpByteData + 18 + tmpPieceCount * 4);
+
         mActionList.clear();
         mpPlayer->think(&mActionList);
-        
+
         GamePlayer_ActionList::iterator it;
         int byteCounter = 0;
-        char* tmpSendData = new char[256];
+        char *tmpSendData = new char[256];
         tmpSendData[byteCounter++] = '|';
         tmpSendData[byteCounter++] = 'r';
         tmpSendData[byteCounter++] = 'p';
         tmpSendData[byteCounter++] = '|';
-        if (mSendLength == 0)
-        {
-            for(it = mActionList.begin(); it != mActionList.end(); ++it)
-            {
-                tmpSendData[byteCounter++] = (char)*it + '0';
+        if (mSendLength == 0) {
+            for (it = mActionList.begin(); it != mActionList.end(); ++it) {
+                tmpSendData[byteCounter++] = (char) * it + '0';
             }
-        }
-        else if (!mActionList.empty())
-        {
-            for(int i = 0; i < mSendLength; i++)
-            {
+        } else if (!mActionList.empty()) {
+            for (int i = 0; i < mSendLength; i++) {
                 tmpSendData[byteCounter++] = (char)mActionList.front() + '0';
                 mActionList.pop_front();
-                if (mActionList.empty())
-                {
+                if (mActionList.empty()) {
                     break;
                 }
             }
         }
         tmpSendData[byteCounter++] = '|';
         tmpSendData[byteCounter++] = '\0';
-        
+
         mpNetClient->sendData(byteCounter, tmpSendData);
         //printf("Sending : [%s]\n", tmpSendData);
-        
+
         delete [] tmpSendData;
     }
-    
+
     delete [] tmpByteData;
-    
+
     return execResult;
 }
 
-int KBlocksNetPlayer::formIntFromByte(char * data)
+int KBlocksNetPlayer::formIntFromByte(char *data)
 {
     int value = 0;
     value += ((int)data[0]) & 0x000000FF;
